@@ -2,9 +2,12 @@
     icmplib
     ~~~~~~~
 
+    A powerful library for forging ICMP packets and performing ping
+    and traceroute.
+
         https://github.com/ValentinBELYN/icmplib
 
-    :copyright: Copyright 2017-2020 Valentin BELYN.
+    :copyright: Copyright 2017-2021 Valentin BELYN.
     :license: GNU LGPLv3, see the LICENSE for details.
 
     ~~~~~~~
@@ -29,12 +32,12 @@ from .models import ICMPRequest, ICMPReply, Host, Hop
 from .ping import ping, multiping
 from .traceroute import traceroute
 from .exceptions import *
-from .utils import PID, is_ipv4_address, is_ipv6_address
+from .utils import PID, resolve, is_ipv4_address, is_ipv6_address
 
 
 __author__    = 'Valentin BELYN'
-__copyright__ = 'Copyright 2017-2020 Valentin BELYN'
+__copyright__ = 'Copyright 2017-2021 Valentin BELYN'
 __license__   = 'GNU Lesser General Public License v3.0'
 
-__version__   = '1.2.2'
-__build__     = '201010'
+__version__   = '2.0.2'
+__build__     = '210207'
